pub struct LockPositionCpiBuilder<'a, 'b> { /* private fields */ }Expand description
Instruction builder for LockPosition via CPI.
Accounts:
[writable, signer]funder[signer]position_authority[]position[]position_mint[writable]position_token_account[writable]position_lock[]fusion_pool[]token2022_program[]system_program
Implementations
Sourceimpl<'a, 'b> LockPositionCpiBuilder<'a, 'b>
impl<'a, 'b> LockPositionCpiBuilder<'a, 'b>
pub fn new(program: &'b AccountInfo<'a>) -> Self
pub fn funder(&mut self, funder: &'b AccountInfo<'a>) -> &mut Self
pub fn position(&mut self, position: &'b AccountInfo<'a>) -> &mut Self
pub fn position_mint(&mut self, position_mint: &'b AccountInfo<'a>) -> &mut Self
pub fn position_token_account( &mut self, position_token_account: &'b AccountInfo<'a>, ) -> &mut Self
pub fn position_lock(&mut self, position_lock: &'b AccountInfo<'a>) -> &mut Self
pub fn fusion_pool(&mut self, fusion_pool: &'b AccountInfo<'a>) -> &mut Self
pub fn token2022_program( &mut self, token2022_program: &'b AccountInfo<'a>, ) -> &mut Self
pub fn system_program( &mut self, system_program: &'b AccountInfo<'a>, ) -> &mut Self
pub fn lock_type(&mut self, lock_type: PositionLockType) -> &mut Self
Sourcepub fn add_remaining_account(
&mut self,
account: &'b AccountInfo<'a>,
is_writable: bool,
is_signer: bool,
) -> &mut Self
pub fn add_remaining_account( &mut self, account: &'b AccountInfo<'a>, is_writable: bool, is_signer: bool, ) -> &mut Self
Add an additional account to the instruction.
Sourcepub fn add_remaining_accounts(
&mut self,
accounts: &[(&'b AccountInfo<'a>, bool, bool)],
) -> &mut Self
pub fn add_remaining_accounts( &mut self, accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> &mut Self
Add additional accounts to the instruction.
Each account is represented by a tuple of the AccountInfo, a bool indicating whether the account is writable or not,
and a bool indicating whether the account is a signer or not.
pub fn invoke(&self) -> ProgramResult
pub fn invoke_signed(&self, signers_seeds: &[&[&[u8]]]) -> ProgramResult