pub struct LockPositionInstructionArgs {
pub lock_type: PositionLockType,
}Fields
lock_type: PositionLockTypeTrait Implementations
Sourceimpl BorshDeserialize for LockPositionInstructionArgswhere
PositionLockType: BorshDeserialize,
impl BorshDeserialize for LockPositionInstructionArgswhere
PositionLockType: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for LockPositionInstructionArgs
impl Clone for LockPositionInstructionArgs
Sourcefn clone(&self) -> LockPositionInstructionArgs
fn clone(&self) -> LockPositionInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LockPositionInstructionArgs
impl Debug for LockPositionInstructionArgs
Sourceimpl PartialEq for LockPositionInstructionArgs
impl PartialEq for LockPositionInstructionArgs
Sourcefn eq(&self, other: &LockPositionInstructionArgs) -> bool
fn eq(&self, other: &LockPositionInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for LockPositionInstructionArgs
impl StructuralPartialEq for LockPositionInstructionArgs